Installation — Recipe 0.14.0 documentation

# Installation

## Installing Recipe

### Distribute & Pip

The recommended way to install Recipe is with pip:

    $ pip install recipe

## Download the Source

You can also install recipe from source. The latest release (0.14.0) is available from GitHub.

- tarball

- zipball

Once you have a copy of the source, you can embed it in your Python package, or install it into your site-packages easily.

    $ python setup.py install

### Staying Updated

The latest version of Recipe will always be available here:

- PyPi: http://pypi.python.org/pypi/recipe/

- GitHub: http://github.com/juiceinc/recipe/

When a new version is available, upgrading is simple:

    $ pip install recipe --upgrade

Now, go get a Quick Start.